Code style
----------

* You should follow PEP8 code style.
* Only customisation allowed to PEP8 style are the Flake8 options set in the setup.cfg file:
  * max-line-length = 100
  * max-complexity = 15
* Flake8 checks are part of the CI process validating Pull Requests.
